package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````W"$```````!``````````%`!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````"B=````````*)T`````````
M``$```````$````&````0/L```````!`^P$``````$#[`0``````.`4`````
M``"8%0```````````0```````@````8```!@^P```````&#[`0``````8/L!
M``````#``0```````,`!````````"`````````!0Y71D!````*R7````````
MK)<```````"LEP```````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```!`^P```````$#[`0``````0/L!``````#`!```````
M`,`$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!)````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!)````30```%$```!2````6````%D```!:`````````%P`
M``!=`````````%X```!?````80``````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`^!<`````````````````````
M```#``T`0/L!``````````````````$````28```````````````````````
M``D````1`````````````````````````+H!```1````````````````````
M`````%8!```28````````````````````````!`````28```````````````
M`````````),!```28````````````````````````!@````28```````````
M`````````````,<!```28````````````````````````)\!```28```````
M`````````````````!\````@`````````````````````````-8"```A````
M`````````````````````#<````28````````````````````````#T````2
M`````````````````````````$0````2`````````````````````````(4"
M```28````````````````````````*L"```28```````````````````````
M`$L````2`````````````````````````.T!```28```````````````````
M`````%(````28````````````````````````',"```28```````````````
M`````````%D````28````````````````````````&$````2````````````
M`````````````%P"```28````````````````````````&D````28```````
M`````````````````&\````28````````````````````````'@````@````
M`````````````````````)T"```28````````````````````````)0````2
M8````````````````````````)D````28````````````````````````-@!
M```1`````````````````````````'H"```28```````````````````````
M`!H"```28````````````````````````*`````28```````````````````
M``````P"```28````````````````````````!P#```28```````````````
M`````````-4"```1`````````````````````````#X"```28```````````
M`````````````,("```28````````````````````````-<"```1````````
M`````````````````*<````28````````````````````````)4"```28```
M`````````````````````&0!```28````````````````````````+`````B
M`````````````````````````+\````@`````````````````````````-4`
M```28````````````````````````+H"```28```````````````````````
M`"H"```28````````````````````````-H````28```````````````````
M`````.`````@`````````````````````````&<"```28```````````````
M`````````/H````28````````````````````````(0!```28```````````
M`````````````/\````28````````````````````````$P"```28```````
M`````````````````',!```28`````````````````````````4!```2````
M`````````````````````!8!```28````````````````````````.@!```2
M8````````````````````````&H````28````````````````````````/D!
M```28````````````````````````#,"```28```````````````````````
M`*0"```28````````````````````````!P!```2````````````````````
M`````(T"```28````````````````````````#`!```2````````````````
M`````````.,!```28````````````````````````#<!```2````````````
M`````````````#X!```2`````````````````````````-0"```A````````
M`````````````````$\!```2`````````````````````````,\"```28`@`
M@!\```````!<`@```````+0!```28`D`'%D````````0`````````%X#```2
M8`@`C#,````````<!P````````H$```28`@`6#T```````"8`````````#L#
M```28`@`<"P````````8`````````,@#```28`<`^!<````````0````````
M`($#```28`@`J#H```````"P`@```````.X#```28`@`B"P````````0`@``
M`````+D#```0`!,`>``"`````````````````$P#```28`@`R#(```````#$
M`````````&L#```28`@`O"H```````!D`````````',#```28`@`\#$`````
M``",`````````)<#```28`@`#%0```````!``0```````*P#```2``@`F"X`
M```````T``````````4$```0`!,`V!`"``````````````````$#```28`@`
M""(```````!<`````````,X#```28`@`S"X```````!D`0```````*(#```1
M`!(`<``"```````(`````````.<#```0`!(`>``"`````````````````+X#
M```2``@`W"$``````````````````,4#```28`@`>%,```````"4````````
M``H#```28`@`?#(```````!,`````````"4#```28`@`F"L```````#8````
M`````/L#```28`@`3%4```````"D`0```````-H#```28`@`,#````````#`
M`0````````!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G
M:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U
M;FQI;FL`;65M;6]V90!S=')N8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R
M96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A9&QI
M;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`
M8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?
M97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC
M<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L
M7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V%L;&]C`')E861D:7(`<W!R:6YT9@!S=')N8W!Y
M`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A=&9O<FL`9G!R:6YT9@!?7VQI8F-?
M<W1A<G1?;6%I;@!?7U]E;G9I<F]N`&QI8G!E<FPN<V\`;&EB8RYM=7-L+7!P
M8S8T;&4N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L
M96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P
M;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA
M;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L
M`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/
M4D4``````````@``````%@````````````(``````!```@``````%@``````
M``!(60```````!@``@``````%@````````!S60```````"@``@``````%@``
M``````!-60```````#```@``````%@````````!-6@```````#@``@``````
M%@````````!860```````$```@``````%@````````!?6@```````$@``@``
M````%@````````!@60```````%@``@``````%@````````!D60```````&``
M`@``````%@````````!I60```````'```@``````%@````````#^6P``````
M``C_`0``````)@```!P``````````````!#_`0``````)@```#,`````````
M`````!C_`0``````)@```"T``````````````"#_`0``````)@````P`````
M`````````"C_`0``````)@```"X``````````````##_`0``````)@```"D`
M`````````````#C_`0``````)@```"```````````````$#_`0``````)@``
M`#@``````````````$C_`0``````)@````0``````````````%#_`0``````
M)@```#X``````````````%C_`0``````)@```#D``````````````&#_`0``
M````)@````4``````````````##]`0``````%0````,``````````````#C]
M`0``````%0````8``````````````$#]`0``````%0````<`````````````
M`$C]`0``````%0````@``````````````%#]`0``````%0````D`````````
M`````%C]`0``````%0````H``````````````&#]`0``````%0````L`````
M`````````&C]`0``````%0````P``````````````'#]`0``````%0````X`
M`````````````'C]`0``````%0````\``````````````(#]`0``````%0``
M`!```````````````(C]`0``````%0```!$``````````````)#]`0``````
M%0```!(``````````````)C]`0``````%0```!,``````````````*#]`0``
M````%0```!0``````````````*C]`0``````%0```!4``````````````+#]
M`0``````%0```!8``````````````+C]`0``````%0```!<`````````````
M`,#]`0``````%0```!@``````````````,C]`0``````%0```!D`````````
M`````-#]`0``````%0```!H``````````````-C]`0``````%0```!L`````
M`````````.#]`0``````%0```!T``````````````.C]`0``````%0```!X`
M`````````````/#]`0``````%0```!\``````````````/C]`0``````%0``
M`"$```````````````#^`0``````%0```"(```````````````C^`0``````
M%0```",``````````````!#^`0``````%0```"0``````````````!C^`0``
M````%0```"4``````````````"#^`0``````%0```"<``````````````"C^
M`0``````%0```"@``````````````##^`0``````%0```"H`````````````
M`#C^`0``````%0```"L``````````````$#^`0``````%0```"P`````````
M`````$C^`0``````%0```"T``````````````%#^`0``````%0```"X`````
M`````````%C^`0``````%0```"\``````````````&#^`0``````%0```#``
M`````````````&C^`0``````%0```#$``````````````'#^`0``````%0``
M`#(``````````````'C^`0``````%0```#0``````````````(#^`0``````
M%0```#4``````````````(C^`0``````%0```#8``````````````)#^`0``
M````%0```#<``````````````)C^`0``````%0```#H``````````````*#^
M`0``````%0```#L``````````````*C^`0``````%0```#P`````````````
M`+#^`0``````%0```#T``````````````+C^`0``````%0```#\`````````
M`````,#^`0``````%0```$```````````````,C^`0``````%0```$$`````
M`````````-#^`0``````%0```$(``````````````-C^`0``````%0```$,`
M`````````````.#^`0``````%0```$0``````````````.C^`0``````%0``
M`$4``````````````/#^`0``````%0```$8``````````````/C^`0``````
M%0```$@```````````````(`3#P(9T(XI@((?!```?CA_R'X30P`2````&#U
M/@!(````8"``(3@0``'HI@,(?"``@$X``````````````````````````!@`
M0?C__X(],'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU(?HSII@.)
M?2`$@$X````````````````8`$'X__^"/5!_C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]^'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CUX
M?HSII@.)?2`$@$X````````````````8`$'X__^"/:A^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]L'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CV0?HSII@.)?2`$@$X````````````````8`$'X__^"/4!^C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]"'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CUX?XSII@.)?2`$@$X````````````````8`$'X__^"/>!_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]D'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CUH?HSII@.)?2`$@$X````````````````8`$'X
M__^"/:!_C.FF`XE](`2`3@```````````````!@`0?C__X(]R'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CWP?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/8!^C.FF`XE](`2`3@```````````````!@`0?C__X(]6'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CW0?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/4A_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]('^,Z:8#B7T@!(!.````````````````&`!!^/__@CT0?XSII@.)?2`$
M@$X````````````````8`$'X__^"/3A^C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]8'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CV@?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/8A^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]0'^,Z:8#B7T@!(!.````````````````&`!!^/__
M@CVH?XSII@.)?2`$@$X````````````````8`$'X__^"/<!^C.FF`XE](`2`
M3@```````````````!@`0?C__X(]*'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CVX?XSII@.)?2`$@$X````````````````8`$'X__^"/0!_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]R'Z,Z:8#B7T@!(!.````````
M````````&`!!^/__@CU@?XSII@.)?2`$@$X````````````````8`$'X__^"
M/9A^C.FF`XE](`2`3@```````````````!@`0?C__X(]<'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CUP?HSII@.)?2`$@$X````````````````8
M`$'X__^"/?A_C.FF`XE](`2`3@```````````````!@`0?C__X(]\'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CV(?XSII@.)?2`$@$X`````````
M```````8`$'X__^"/;A^C.FF`XE](`2`3@```````````````!@`0?C__X(]
M.'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW8?HSII@.)?2`$@$X`
M```````````````8`$'X__^"/8!_C.FF`XE](`2`3@```````````````!@`
M0?C__X(],'^,Z:8#B7T@!(!.````````````````&`!!^/__@CWH?XSII@.)
M?2`$@$X````````````````8`$'X__^"/6A_C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]X'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU8
M?XSII@.)?2`$@$X````````````````8`$'X__^"/1A_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]Z'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CW`?XSII@.)?2`$@$X````````````````8`$'X__^"/;!^C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]T'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CV8?XSII@.)?2`$@$X````````````````8`$'X__^"/=A_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]4'Z,Z:8#B7T@!(!.````
M`````````````@!,/(!?0CBF`@A\\/_!^_C_X?L0``'X<?\A^'``@?AH`*'X
M<`"!.&@`H3A\`&&0?`!A..W[_TL8`$'H````8%"`HN@```!@6(!BZ'@KI'Q1
M^?]+&`!!Z````&!@@"+I````8#B`XNL``,F+```>+$``@D"M^/]+&`!!Z```
M`&```",LT)%B^!``@D`!`&`X4?[_2Q@`0>@I_?]+&`!!Z```?X#]^?]+&`!!
MZ*<+PYL``'^`[?G_2Q@`0>CZ!2.)`@`I8?H%(YD``'^`U?G_2Q@`0>CZ!2.)
M`0`I8?H%(YE^`&'H`P#C.P0`8SBT!V-\M`?_?R0?8W@)^?]+&`!!Z'X`0>EP
M`.'H````8````#G`D6+X>!MF?```)^D```HL```C^?[_(CWXW"DY"``C^0``
M`&!P@2+I$``C^?[_(CW[W"DY&``C^?__*CD@`"EY`0`I.0@`@4$!`"`Y`0`I
M+`0`2#FT!TI]`0`(.20?2GG__RDY%%*F?,@`@D```"`Y````8-"18NC^_X(\
M``#@.""LA#@``"7Y>/OE?T7[_TL8`$'H>1M_?!@`@D````!@T)%BZ.W\_TL8
M`$'H>!M_?````&#0D6+HF?G_2Q@`0>C^_V(\!]MC."4$`$@``",L/`""0```
M`&#(D2+I```I+!@`@D#^_V(\O-IC.`$$`$@```!@R)%B^````&#(D6+H```C
M+`@`@D')&P!(````8-"18NC]]_]+&`!!Z'7Y_TL8`$'HD``A.'C[XW\D-@!(
M)!\%>2HHIWPJ4:9\$/__2P`````````!@`(```(`3#PD74(X*`",@!1BA'QX
M"R-\Y`8A>````#CA_P'XI@,(?!$``$B$V0$``@!,//A<0CBF`@A\"`"C./[_
MXCP<VN<X_O_"//B8QC@````Y$``!^.'_(?@"`(/H_O]B/("@8SC!^?]+&`!!
MZ"``(3@0``'HI@,(?"``@$X``````````8````````!@````8````&`"`$P\
MD%Q".````&````!@>(%B.'B!(CD`&"E\(`""30```&`(@(+I```L+"``@DVF
M`@A\I@.)?1```?CA_R'X&`!!^"$$@$X8`$'H(``A.!```>BF`PA\(`"`3@``
M0F`"`$P\,%Q".````&````!@>(%B.'B!@CA0((-\=!Z$?'0.A'R5`81\(`""
M30```&`0@(+I```L+"``@DVF`@A\I@.)?1```?CA_R'X&`!!^"$$@$X8`$'H
M(``A.!```>BF`PA\(`"`3@```&```$)@`@!,/,!;0C@```!@>($BB0``"2P@
M`(),I@((?````&`8@"+IZ/^A^_#_P?L``"DL$``!^,'_(?@8`$'X%`""00``
M`&``@6+H.??_2Q@`0>C__T(]___"/P```&"`@2+I6'Q*.5!\WCM04-Y___^B
M/W0>WG]0?+T[___>.T#P*7P\`(!`.`#A^P```&"`@>([`0`I.20?*GD``#_Y
M*E"=?:8#B7TA!(!.&`!!Z```/^E`\"E\W/^`03@`X>M]_O]+````8""`(ND`
M`"DL%`""0?[_8CRT&6,XR?7_2Q@`0>A``"$X`0`@.0```&`0``'HZ/^AZ_#_
MP>MX@2*9I@,(?"``@$X```!@````8```0F`"`$P\L%I".````&`H@"+I```I
M+#P`@D&F`@A\````8/[_8CR(@8(XM!EC.!```?CA_R'X_?/_2Q@`0>@@`"$X
M$``!Z*8#"'Q`_O]+``!"8#C^_TL"`$P\7%I".*8""'S5,@!(>1M\?+'_(?@`
M`,`[)`""00```&`P@"+I``#`.W@CFGQXXX5_``"IZP``/2P<`()`4``A.'CS
MPW_0,@!(/0`)*!0`@D$!`*4X```EB0``*2SL_X)`4"B\?'CKNW^T![]\``#;
MZP``/BS(_X)!>/OE?WCCA']X\\-_M?;_2Q@`0>@``",L*`""0*[X/GT]``DL
M'`""0%#8O7\!`/\[=!Z]?Q3ZWG\``+J3B/__2P@`>SNP__]+``````````&`
M!@```@!,/(Q90CBF`@A\$``!^)'_(?AD`($X\(\MZ6@`(?D``"`Y%?__2V@`
M(>GPCTWI>5(I?0``0#D,`()!D?3_2Q@`0>AP`"$X$``!Z*8#"'P@`(!.````
M``````&``````@!,/"Q90CBF`@A\\/_!^_C_X?MX&W]\$``!^('_(?CPCRWI
M:``A^0``(#ED`,$[>//$?WC[XW^A_O]+```C+"``@D!H`"'I\(]-Z7E2*7T`
M`$`Y/`""017T_TL8`$'H9@`AZ20?*7GX_TDY````8#"`(ND``"GI%%(I?1``
M2>D``"HL"0!)^?3_@D"D__]+@``A.'@Q`$@``````````8`"```"`$P\B%A"
M.*8""'SY,`!(P?XA^'D;?GSPCRWI^``A^0``(#EH`()!```^B0``"2Q<`()!
ME?'_2Q@`0>AY&WQ\3`""0?[_8C_^_T(__O\B/W/:>SMRVEH[==HY.V@``3MX
MXX-_I?3_2Q@`0>AY&W]\.`""0'CC@W^Q]O]+&`!!Z'CSPW_%\O]+&`!!Z/@`
M(>GPCTWI>5(I?0``0#G4`()!*?/_2Q@`0>@3`/\[>-MD?WC[XW\U\_]+&`!!
MZ```(RR@_X)!>--$?WC[XW\=\_]+&`!!Z```(RR(_X)!>//#?ZGV_TL8`$'H
M>!M]?'C[XW^9]O]+&`!!Z!0:?7P"`&,XM`=C?&7W_TL8`$'H>/OF?WCSQ7]X
MRR1_>!M]?`WS_TL8`$'H>,,$?WCKHW]=\?]+&`!!Z/__`RQXZZ-_*`""08``
M(8$F!"E5`$`)+!@`@D"Y_O]+>.NC?_'S_TL8`$'H`/__2P7Q_TL8`$'HZ/__
M2T`!(3C(+P!(``````````&`"````@!,/`170CBF`@A\^/_A^W@;?WP0``'X
M,?\A^"@`@3CPCRWIN``A^0``(#G9]O]+&`!!Z```(RQ4`()`0``A@28$*54`
M0`DH$`""0?__*FT`H`HL'`""0`(`@#AX^^-_!??_2Q@`0>@T`&-\?MEC5+@`
M(>GPCTWI>5(I?0``0#D4`()!P?'_2Q@`0>@``&`XX/__2]``(3A0+P!(````
M``````&``0```@!,/%Q60CBF`@A\T2X`2%'_(?AX&W]\>".>?/"/+>EH`"'Y
M```@.0``)(D]``DL"`""0`$`Q#MX\\-_(?7_2Q@`0>AD`($X>!M]?'C[XW^Y
M^_]+>1M\?$@`@D$!]?]+&`!!Z$`8/7RT`(%!```@.:Y(7GT``"HLKDE<?0$`
M*3GP_X)`:``AZ?"/3>EY4BE]``!`.7`!@D$%\?]+&`!!Z````&`P@&+K```@
M.0``.^OX_QDYM`<\?0$`*3DD'RIY*E!(?0``*BSL_X)`````8+B!(H$"`)PX
MM`>$?"0?A'@```DLX`""07C+(W^Q[_]+&`!!Z```(RP``'OXB/^"00$`/#D`
M`%OI````.;0'*7TD'REY*DD*?60`@9-X^^E_``!)B0``*BP,`()!/0`**,P`
M@D!F`('K````8#"`8NM02#]]`@!].+0'*7T42F-\``!;Z^GT_TL8`$'H)!^<
M>P``(RPJX7I\'/^"068`(>D``%OI____.R0?*7DJ2"I]`0!?C7A+*'T!`"DY
M```J+/__29D,`()!/0`**.3_@D`]`$`Y``!(F0``0#FN4!Y]```H+*Y1"7T!
M`$HY\/^"0,3^_TL!`"`Y````8'@C@WRX@2*1:?3_2Q@`0>AY&WI\I/Z"020?
MA7MXRR1_T?+_2Q@`0>@``%O["/__2P$`*3D@__]+L``A.`PM`$@`````````
M`8`'```"`$P\1%1".*8""'P```!@.(`BZ1```?CA_R'X``!I@$7O_TL8`$'H
M````8$"`HNC^_\(\_O^"/(`8QCA[VH0X)?'_2Q@`0>@@`"$X$``!Z*8#"'P@
M`(!.``````````&``````@!,/.!30CBF`@A\^/_A^P```&`X@.+K$``!^-'_
M(?@``'^`W>[_2Q@`0>AY__]+``!_@,WN_TL8`$'H_O_B//[_HCSWW.<X_O^"
M/````#EX.^9\J+NE.)?:A#@%[_]+&`!!Z#``(3A<+`!(``````````&``0``
M`@!,/&A30CBF`@A\[2L`2&'?(?CPCRWI>"`A^0``(#D)[?]+&`!!Z&@`X3O^
M_\(\_O^"/'@;97RLVL8XL-J$.'C[XW]P$*$[P>[_2Q@`0>AX^^-_`!"@.'CK
MI'\``.`[Z?'_2Q@`0>@```,L.`"`0;0'?GP!`'XXM`=C?,WR_TL8`$'H>1M_
M?!P`@D%X\\5_>.ND?Q7S_TL8`$'H```@.:[Q/WUX("'I\(]-Z7E2*7T``$`Y
M#`""0?'M_TL8`$'HH"`A.'C[XW]H*P!(``````````&``P```@!,/)!20C@H
M__]+`````````````````@!,/'A20CBF`@A\)H"0?0@`@9'1*@!(H>XA^'@;
M?GS^_V(\O-IC.'@CGWSPCRWI^!`A^0``(#F]^/]++P"`.'@;>WQX\\-_D>S_
M2Q@`0>@``",L,`""0?[_8CQX\\1_Q=IC.,'[_TOX$"'I\(]-Z7E2*7T``$`Y
M>`&"03WM_TL8`$'H>//#?_[_0C_M\/]+&`!!Z-+:6CO^_R(_>--$?_[_XCZT
M!WU\>/OC?XWQ_TL8`$'H_O_"/@``@#H``#LN<]HY.W@;?WP````[`0"].]3:
M]SJEV]8Z^`"!.V@`H3H`@)1B```_+'#_@D$``#^)```)+`@`@D!XRS]_(`"2
M07C[Y']XVV-_T>S_2Q@`0>AXTT1_```C+,@`@D%X^^-_6?#_2Q@`0>BT!VE\
M__]).;0'2GVN4!]]+P`(+)``@D$42CU]_P\)+!#_@4%X\\=_>+OF?GC[Y7]X
ML\1^>..#?[GL_TL8`$'H>*ND?GCC@W\)Z_]+&`!!Z```(RQ<`()`@``A@28$
M*54`H`E\3`""0`$`@#AXXX-_0?'_2Q@`0>@``",L-`""0/[_8CQXXX1_Q=IC
M.''Z_TMXXX-__>__2Q@`0>AX&WY\H/[_2ZY1'W]X4TE]6/__2WC31'\``&`X
M6?#_2Q@`0>AX&W]\^/[_2V`1(3AX\\-_"`"!@2"!D'T<*0!(``````````.`
M#```>!MI?'A+(WT0``!(+P`**`$`*3GP_X)!``!)B0``*BSL_X)`(`"`3@``
M``````````````(`3#PT4$(XI@((?/C_X?MY&W]\$``!^-'_(?@0`()!```_
MB0``"2P0`()`_O]B/'/:8S@4`0!(_>[_2Q@`0>C__R,Y%$J_?'@;:7P4&G]\
M__]C.$`8/WP,`(%!__\_+`@`@D`!`"`Y`0`I+/__*3F\`()!``!%B2\`"BR@
M`()!0"@_?%`H/WT!`"DY"`"!0`$`(#D!`"DL__\I.9``@D$``$6)__\%.2\`
M"BQX`()`__]%.5`H/WU`4#]\#`"!0?__/RP(`()``0`@.0$`*2S__Z4X__\I
M.1``@D$``$6)+P`*+.C_@D%0*+]\``!@.`(`)3D`$"DH6`"!00```&`!`*4X
MP($B.7C[Y']X2R-]I>W_2Q@`0>@X``!(__^E.$C__TMX0P5];/__2T`H/WR`
M_X)````_B?[_8CS4VF,X+P`)+.C^@D$M[O]+&`!!Z#``(3C$)P!(````````
M``&``0```@!,/-!.0CBF`@A\_O]B/-;:8SA))P!(4?\A^/[_PC_^_Z(_]]K>
M.[S:O3O^_^(__O^"/Q/;_SL=VYP[\(\MZ8@`(?D``"`Y_O\B/8H8*3D``,GH
M"`#IZ!``">D8`$GI(``IH6``P?AH`.'X<``!^7@`0?F``"&Q-?7_2_[_8CS?
MVF,X*?7_2_[_8CSGVF,X'?7_2_[_8CSPVF,X$?7_2WCSPW\)]?]+_O]B/`?;
M8SC]]/]+>.NC?_7T_TMX^^-_[?3_2WCC@W_E]/]+_O]B/"?;8SC9]/]+_O]B
M/,7:8SC-]/]+_O]B/#';8SAA]/]+>1MD?`P`@D%XXX-_@??_2_[_8CQ"VV,X
M1?3_2WD;9'P0`()!_O]B/$W:8SAA]_]+_O]B/%3;8S@E]/]+>1MD?#@`@D%X
MZZ-_1??_2_[_@CQX\\-_@-N$.#7W_TN(`"'I\(]-Z7E2*7T``$`Y4`""0;'H
M_TL8`$'H_O]B/&3;8SC=\_]+>1MD?`P`@D%X^^-_N/__2_[_@CP*`*`X==N$
M.'$`83@=ZO]+&`!!Z```(RR<_X)`>P"!.-3__TNP`"$XY"4`2``````````!
M@`0```(`3#P034(X````8`B!(H'__PDL8`""0*8""'S^_V(\$]MC.!```?BA
M_R'X8?/_2P``0#D``",L'`""00``(XD``"DL$`""03``*6G__TDQ$$E*?0``
M`&!@`"$X"(%"D1```>@```!@I@,(?`J!8N@@`(!.````8`J!8N@@`(!.````
M``````&``````@!,/(1,0CBF`@A\$``!^.'_(?AQZO]+&`!!Z.GK_TL8`$'H
M```C+`@`@D$``&/H(``A.!```>BF`PA\(`"`3@`````````!@`````(`3#PX
M3$(XI@((?+DD`$B!_R'X_O^"/W@;?WR"VYP[>..#?Y'R_TMX^^1_>1M^?!``
M@D$``#Z)```)+!0`@D!XXX-_H?7_2X``(3BP)`!(">K_2Q@`0>@``",L[/^"
M0'C[XW_5ZO]+&`!!Z'@;?7QX\\-_Q>K_2Q@`0>@4&GU\`@!C.)7K_TL8`$'H
M_O_"//[_@CREVX0X>//'?W@;?7S2VL8X>/OE?S'G_TL8`$'H>.ND?XS__TL`
M`````````8`$```"`$P\=$M".*8""'P``"`YF($I8=DC`$C__P`\_O]"/Q!^
M`&"\VEH[>!M[?'C30W]J`2%\%`HI?:"!X3OPCTWI``!)^0``0#D```!@$($B
MZ<!^/_D```!@&($BZ<A^/_D```!@(($BZ=!^/_D```!@*($BZ?!^/_D```!@
M,($BZ?A^/_D```!@.($BZ0!_/_D```!@0($BZ0A_/_D```!@2($BZ1!_/_D`
M``!@4($BZ1A_/_D```!@6($BZ=A^/_D```!@8($BZ>!^/_D```!@:($BZ>A^
M/_D9\?]+>1M^?$P`@D$``#Z)```)+$``@D%5_O]+>//#?[WI_TL8`$'H>!M^
M?```(#F8@2EA%`HI?0``2>GPCRWI>4I*?0``(#GD!8)!D>7_2Q@`0>C-_?]+
MT'Z_.WD;?GR0`8)!>//#?_[_@C\QZ?]+&`!!Z/__WCN9VYP[I`]C>`$`8SCY
MZ?]+&`!!Z'@;>7QX&WU\`0"^C```)2QL`8)`Z'Z_.PD`W>L``#XL/`""07CS
MPW]E\/]+>1M^?.C_@D$``#Z)```)+-S_@D'5\O]+```C+-#_@D%X\\-_`>G_
M2Q@`0>AX&WY\N'Z?.P``/BP<`()`"0"\ZP``/2Q(`8)!```]B0``"2P8`8)`
M>//#?_[_XCZ)Z/]+&`!!Z-3:]SIX&WQ\>,LC?W7H_TL8`$'H%!J<?P0$G#NT
M!YQ_>..#?SWI_TL8`$'H_O_B//[_@CQXRRA_GMOG.'B[YGYX\\5_H]N$.'@;
M?7S5Y/]+&`!!Z,`!@#AXZZ-_)>3_2Q@`0>C__P,LR`""0#7I_TL8`$'H`@#C
MZ!$`!RRT`()!````8$B`(ND``+OH_O^"/'CKIG^LVX0X``!IZ&7F_TL8`$'H
M``#`.VC^_TM1[_]+>1MI?"``@D$``"F)```)+!0`@D']Y_]+&`!!Z'D;?GQX
M_H)`"0!]Z```(RS0_X)`_O_"/Y+;WCM@_O]+>.NC?WCCA'\MY/]+&`!!Z`(`
MO3MX_O]+>.NC?WWQ_TL``",LR/Z"07CKHW^IY_]+&`!!Z'@;?GRL_O]+``#`
M.\3^_TL@?Y\X>.NC?TGH_TL8`$'H>1MX?"P`@D$```!@2(`BZ0``N^C^_X(\
M>.NF?^?;A#@``&GHG>7_2Q@`0>@X__]+.'\_@28$*54`0`DLS/^"0#Q_WX/]
MY?]+&`!!Z``8/GRX_X)`.'\_@?X%*57``0DLJ/^"0'CC@W^YY_]+&`!!Z'@;
M?GS^_V(\C=MC.$'N_TL``",LJ`&"0```.^MXRR-_L>;_2Q@`0>@#``,LM`=\
M?(0`@4#\_WPX_O^"/#K<A#@4&GE\[>+_2Q@`0>@``",L9`""0`0`'"P8`()!
M^_^<.[0'G'^NX#E]+P`)+$@`@D`(`)OK```\+#P`@D%XXX-_4>;_2Q@`0>@#
M`",H*`"!0/S_8SC^_X(\/]R$.!0:?'R1XO]+&`!!Z```(RP(`()`>..9?Q7Z
M_TL``",L\`&"0```@#AXRR-_J>;_2Q@`0>AY&WQ\V`&"00(`H#CN_X`XT>3_
M2Q@`0>CX?W\[!@"@.'C;9']XXX-_F>7_2Q@`0>CX?S^)```)+-@`@D#Y?S^)
M0P`)+,P`@D#Z?S^)00`)+,``@D#[?S^)0P`)++0`@D#\?S^)2``)+*@`@D#]
M?S^)10`)+)P`@D`"`*`XQO^`.'CC@W]=Y/]+&`!!Z"D`H#AXVV1_>..#?RGE
M_TL8`$'H_O\"/7C;9W_WW`@Y_O^"/'B[YGYXZZ5_1-R$.'CSPW_AX?]+&`!!
MZ'CKHW_UXO]+&`!!Z'C30W]X\\1_T>__2WCSPW_M^?]+J/O_2P``F^M1Y?]+
M&`!!Z'@;9'QXXX-_D?/_2WD;>7Q$_H)`//[_2P``H#@``(`X>..#?___`#O!
MX_]+&`!!Z/A_/SL@!!A741H`2````&!X&WM\>,,%?WC+)']XXX-_>>3_2Q@`
M0>@```,LM`=E?'``@4%XXX-_L'^?.UWC_TL8`$'H>-MD?WCC@W_^_P(_R'\_
M.]D;`$@```!@``!@.YG;&#NNV+Q\>,LC?WC#!'\!`'L[`@`Y.P'A_TL8`$'H
M%``[*.#_@D```"`Y_O\"/??<"#G(?_\X\'\_F>C^_TMXRR1_>-MC?T4:`$@`
M``!@9/__2_[_@CS^_V(\@-N$.!/;8SC![O]+_O_B/_[_@C_WW/\[8=R<.\'>
M_TL8`$'H_O^"/'C[Z']XN^9^>.NE?W@;9WQ3W(0X>//#?WW@_TL8`$'HP`&`
M.'CSPW_-W_]+&`!!Z/__`RR(_H)`W>3_2Q@`0>@``".!$0`)+'3^@D!IWO]+
M&`!!Z`$`&#MX^^E_M`<8?WB[YGYX&V=\>,,(?WCKI7]XXX1_>//#?QW@_TL8
M`$'HH/__2P``(>AX\\-_&!T`2``````````!@`D```(`3#Q81$(XI@((?-T<
M`$B!_R'X````8#B`XNL``'^`6=__2Q@`0>AX&WY\``!_@$G?_TL8`$'HL``^
MB;$`(YG^_V(\]]IC.(WJ_TL``",L'`""00``(XDQ``DL$`""0`$`(XD```DL
M"`""027U_TL``'^`!=__2Q@`0>C^_X(\`P#`.`$`H#ARW(0X#>'_2Q@`0>AY
M&WY\6`""00``?X#9WO]+&`!!Z!``/NG^_Z(\=-RE.```B>BAW_]+&`!!Z!``
M/ND``"GI#``I@4``*74@`()!``!_@*'>_TL8`$'H$``^Z0``B>C1W_]+&`!!
MZ```?X"%WO]+&`!!Z/[_@CP#`,`X`0"@.'G<A#B-X/]+&`!!Z'D;?GQT`()!
M_O]B/,7:8SBQZ?]+>1M]?"@`@D$``'^`1=[_2Q@`0>@0`#[I>.NE?P``B>@1
MW_]+&`!!Z#P``$BE[_]+>1M]?```?X#0`()!%=[_2Q@`0>@0`#[I>.NE?P``
MB>CAWO]+&`!!Z'CKHW^5W_]+&`!!Z```?X#IW?]+&`!!Z'@;?GP``'^`V=W_
M2Q@`0>C^_X(\`0"@.'O<A#@%W/]+&`!!Z/[_HCR0W*4X>!MD?'CSPW^-WO]+
M&`!!Z```?X"AW?]+&`!!Z```(#FQ`".9_O]B/+S:8SCEZ/]+````8```(RS(
MD6+X3`""0````&#`D6+HX?;_2P```&```",LR)%B^#``@D#^_V(\EMQC.''>
M_TL8`$'H2=W_2Q@`0>@```!@P)%"Z1``/ND``*KH_/[_2P```&#(D6+HP`&`
M.````&"X@>([^=S_2Q@`0>@1``,L>!MF?"P`@D$!`",Y`0`)*"``@4`($#_I
M$!"_Z/[_8CRWW&,X``")Z`7>_TL8`$'H@``A.(`:`$@``````````8`#```"
M`$P\J$%".*8""'SP_\'[^/_A^W@;?WP0``'XD?\A^%WQ_TL=\?]+>!M^?'7T
M_TL``",L4`""00``/RQ(`()!```_B0``"2P\`()!_O^"/'CSPW^>VX0X<=__
M2Q@`0>@`&#Y\(`""0'``(3AX^^-_$``!Z/#_P>OX_^'KI@,(?*CH_TMP`"$X
M`!H`2``````````!@`(```(`3#P004(XI@((?#@`PSA]&0!($?TA^/"/+>FH
M`B'Y```@.0@`(#FF`RE]*``!.0``1NDL-"!]$``(.0@`QCCP_RCY(,))>2(`
M1WDN!"E5($9*>7A3*7THP.IX>%,I?1Y"YU1X.RE]^/\H^<3_`$)``"`Y(``!
M.:8#*7UP`"CI2`#HZ!@`2.EX.BE]>%(I?0D`2.EX4BE]I`\J><(/*7EX2TE]
M(``I>8``*/G0_P!"```#Z"``8^D(`(/H$`##Z!@`H^C"+@EXI"X'>'A+YWPH
M`"'I9/"*>"``YWAX*LA\."`(?63P'WB"6BD]>"H(?9EY*3D46BE]%$KG?(+P
MB7AX2TI],``AZ11"YWP@`%QY(`#^>'CBR'R"6BD].``(?9EY*3EX,@A]%"HI
M?11*"'W(+NEXXB[G>'@[)WV"\`EX%#H(?3@`X>AX2_]_>/I)?2``&GDX\"E]
MR"X*>8):YSQXXBE]F7GG..(N"'D4,N=\>$-(?10Z*7UD\,I[%$(I?4```>F"
M\-Y[>/-*?2``_7MX4NQ_(``[>8):"#TXT(Q]F7D(.7CJC'T4XHA_9/!'>\@N
M*'F"\%I[XBXI>7C3YWQX2PE]%.*,?11*C'T@`%YY>#I)?4@`0>ED\&A[.-@I
M?8+P>WMX\BE](`"<>8):2CUXVPA]F7E*.2``^G@4ZJI_4`!!Z63PGWL4ZBE]
MR"Z=>>(NC'D@`!MY>&.L?X):2CUX0OU\F7E*.3C@O7\48BE]%/+*?WC2O7\@
M`#AY%/*]?\@N/GGB+BEY>$O)?X+PG'L42KU_6``AZ7CC_W]X^AY]9/`*>SC`
MWG^"\!A[@EHI/7C#2GV9>2DY(`"Y>Q3227]@`"'IR"ZL>WC:WG_B+KU[>.N=
M?132WG^"6BD]>%+L?YEY*3D4ZMY_%-II?SC(C'UD\"E[@O`Y>WC+*7T@`-U[
MR"['>^(NWGMX\_Y\>$I'?2``_'LXZ.=\9/"H>X+PO7MXZPA]>.*,?7A"/7T4
MVHQ](``[>7``(>D@`%IY:`!!Z13RC'UXTN=\(`"8>8):*3V"6DH]F7DI.9EY
M2CD4TDE_>``AZ13BBG_(+HIYXBZ,>7AC3'T4XN=\%&+G?#C`O7]D\!][@EHI
M/8+P&'L@`/EX>,/_?\@N_GAXVKU_F7DI.>(NYW@4VFE_@``AZ7@[QW\4TKU_
M>/H>?2``''D4.KU_.,C>?R``IWO(+JQ[>.+>?^(NO7MXZYU]%-K>?V3P*GN"
M6BD]@O`Y>Q3JWG]XRTI]F7DI.2``V'MX4NQ_%.*)?\@NR7OB+MY[(`#Z>WCS
M/GTX.(Q]9/#I>(+PYWAX.RE]>-*,?7A*1WT4XHQ]%/*,?3C`YWQD\`A[@O`8
M>WC#"'T@`)EY(`!;><@NG7F(`$'IXBZ,>2``/'EX8ZQ_>$(]?9``(>F"6DH]
M>-KG?)EY2CDXR+U_@EHI/1322G^9>2DY%-+G?!3::7^8`"'I%&+G?"``['C(
M+OYX>.*]?^(NYWAX.\=_%-J]?X):*3T4.KU_9/`_>YEY*3F"\#E[(`"X>WC+
M_W\4XHE_R"ZI>^(NO7MX^AY]>.L]?:``(>D@`!IY.&#>?V3PBGF"\(QY>&-*
M?7C2WG]X4NQ_%.+>?X):*3T4ZMY_(`#[>SC`C'V9>2DY9/`'>X+P&'L@`-E[
M>,/G?!3227]XVHQ]R"[)>^(NWGL@`%QY>/,^?132C'UX.DE]J`!!Z13RC'TX
MR"E]9/`_>X+P.7L@`)UY>,O_?\@NB'GB+HQY(`#Z>'AC#'V"6DH]>/KH?+``
MX>B9>4HY%-IJ?WCB*7T4VBE]..@(?8):YSP48BE]F7GG."``*GD4XH=_>-((
M?<@N)WGB+BEY>$OI?!3B"'VX`.'H%$H(?63PJ7N"\+U[(`#^>WCK*7UD\%UY
M>$K_?R``.7DX4/]_@O!*>7A3O7^"6N<\>.HJ?<``(>F9>><X(``<>1321W]X
M\O]_XBX'>2@H"'D4TO]_>#L(?8):*3T40A]]..!*?9EY*3GB+@=Y%/+)?WC*
M2GTH*`EY%/)*?7@[*7UD\)M[%$I*?<@`(>F"\)Q[>.-[?R@H7WEXVKQ_B/`>
M>=IN*3UX0IQ_H>LI.:+P"'D4RBE_XBY)>7A+_W_0`"'I>$/(?^``P>MX0F=_
M(`"<>Q3*G'\@`+U[VFXI/7A2YWRAZRDY%/J<?Q3J*7T@`.=X%#HI?2@HG7OB
M+H=[(`![>W@[O7_8`.'HVF[>/Q3JJ7^(\$EYHO!*>>(NOWMX4RI]VF[G/'A2
M"7VAZ^<X>.(I?13:YWP@`"EY(``(>11*YWPH**E[>/LI?8CPGWNB\)Q[%$KG
M?'CC_'^AZ]X[\`#AZWCB27T40MY_>.HI?2@HZ'@@`"EY(`!*>11*WG_B+NEX
M>$L(?8CPJ7NB\+U[%$+>?WCK/7WH`"'IXB[(>XCP^WC:;O\_H>O_.]IN*3VA
MZRDY%%(I?7CJBG]X.DI]HO#G>"``2GEX.WM_%%(I?2@HRGMX0TI](`"<>Q12
M*7UXVJI_>/)*?13B_W\@`$IYXBXH>112_W\H*"IY>$-*?8CPR'L44O]_^`!!
MZ:+PWGMX\QY](`"]>WCR:'_B+N=[VFY*/7A*"'VAZTHY(``(>13J2GV(\#QY
M%$)*?2@HZ'MX.PA]``'AZ*+P*7EX2YQ_(`![>WCBR7\40DI]VF[G/'CZ*7VA
MZ^<X(``I>13:YWSB+DAY%$KG?"@H27EX0RE]"`$!Z8CP^WNB\/][%$KG?'C[
M>W\@`-Y[>-J)?]IN"#UX4BE]H>L(.13R"'T@`"EYXB[_>!1*"'TH*.EXB/!=
M>7C[*7VB\$IY%$H(?1`!(>EX4[U_>.IJ?R``G'MX.DI]XBX?>=IN*3T@`$IY
MH>LI.2``>WL4XBE]B/#\>!12*7TH*`IY>/M*?1@!X>NB\.=X>#N<?Q12*7UX
MXJI_XBXG>=IN_S]X0DI]H>O_.R``2GD4VO]_B/`>>112_W\H*"IY>#M*?:+P
M"'D44O]_(`%!Z7A#WG]X\HA_(`"]>WA*"'WB+N=[VFY*/2``"'FAZTHY(`"<
M>Q3J2GV(\#UY%$)*?2@HZ'MX.PA]*`'AZ*+P*7EX2[U_%$)*?7CJR7_B+DAY
MVF[G/'CZ*7VAZ^<X(``I>13BYWR(\/Q[%$KG?"@H27EX0RE],`$!Z:+P_WMX
M^YQ_%$KG?'CBJ7\@`-Y[VFX(/7A2*7VAZP@Y(``I>13R"'WB+O]X%$H(?2@H
MZ7AX^RE]B/!>>11*"'TX`2'IHO!*>7A3WG\@`+U[>/**?^(N'WG:;BD]>#I*
M?:'K*3D@`$IY%.HI?8CP_7@44BE]*"@*>7C[2GU``>'KHO#G>'@[O7\44BE]
M>.K*?R``G'O:;O\_>$)*?:'K_SL@`$IY%.+_?^(N)WD44O]_*"@J>7@[2GV(
M\!QY%%+_?T@!0>FB\`AY>$.<?R``WGMXXJA_B/`[>=IN2CUX2@A]H>M*.2``
M"'D4\DI]*"C^>Q1"2GWB+NA[>$/>?Z+P*7D4\LI_4`%!Z7A+>W\@`+U[B/#H
M>^(NR7O:;NH\>-J*?WCZ2GVAZ^<X%.KG?"``2GD44N=\6`%!Z:+P_WMX^Q]]
M*"C=>WA+O7]X^FE_VFX*/2``G'MX\BE]H>L(.13JIW\4X@A](``I>>(NJGL4
M2@A]R"ZI>WA3*7VB\,I[%$H(?8CPR7MX4SY]8`%!Z2``>WL@`!IYHO"G>R``
MW'O:;BH]>/+J?WCJ2GVAZRDY%-HI?2``2GD44BE]R"X*>>(N"'D@`/][>$-(
M?8CPJGMX.T=]%$(I?2``^WAX.\A_.-C*?SC0"'UH`<'K>%,(?1N/0#W<O$IA
M9/!=>R``2GF"\%I[%/+*?WC3O7\4^OY_(``Y>13Z"'UXZ^=\R"X_>>(N*7EX
M2^E_.,CG?#C8OW\42BA]>/OG?'`!X>L@`"AY9/`L>X+P.7MXRXQ](`"Z>Q3Z
MZG]X8[Y_%.*??\@N/WGB+BEY%.+G?'A+Z7\@`)QY%$KG?'@!(>DXX+U_.$#>
M?R``^'AXZ]Y_%$HJ?13::7_(+NEXXB[G>!3:WG]X.R=]%#K^?&3P'GF"\`AY
M(`#Y>'A#WG^``0'I>/.)?3C@S'\XP"E](`#;>Q1""GUX8RE]%-)(?\@NZ'CB
M+N=X%-(I?7@[!WUD\`A[@O`8>Q0Z*7UXPPA](``Z>2``'7EX0]]_..C'?SC(
M_W]X._]_B`'AZ&3P3'L4.NI\%.*'?\@N)WGB+BEY%.+_?WA+Z7P42C]]9/`_
M>X+P.7L@`#AY>,O_?WC[!WTXZ.A_.-#G?(+P6GMX0^=\D`$!Z7C3C'UX8_Y_
M(`#\>SC`WG\40@I]%-IH?\@N*'GB+BEY%-KG?'A+"7T@`)MYH`$!Z11*YWPX
MV.E_>$O>?Y@!(>D@`/EX%$(*?13BB'\42BI]%.JI?\@NZ7CB+N=X%.K>?W@[
M)WT4.OY\9/`>>X+P&'L@`/IX>,/>?\@NZ'AX\XE]XB[G>#C8S']X.P=].,@I
M?63P*'N"\#E[>&,I?7C+"'T4XBE]>$/??R``''D4.BE].-#_?SC@QW\@`#AY
M>#O_?Z@!X>@@`-U[9/`,>Q0ZZGP4VF=_R"XG>>(N*7D4VO]_>$OI?!1*/WUD
M\%][@O!:>R``.7EXT_]_>/L'?3C@Z'\XP.=\@O`8>WA#YWRP`0'I>,.,?7AC
M_G\@`/M[.,C>?Q1""GT4ZJA_R"XH>>(N*7D4ZN=\>$L)?2``G7G``0'I%$KG
M?#CHZ7]X2]Y_N`$AZ2``^G@40@I]%-IH?Q1**GT4XHE_R"[I>.(NYW@4XMY_
M>#LG?10Z_GQD\#Y[@O`Y>R``^'AXR]Y_R"[H>'CSB7WB+N=X..C,?W@[!WTX
MT"E]9/!(>X+P6GMX8RE]>-,(?13:*7UX0]]_(``;>10Z*7TXP/]_.-C'?R``
M.7EX._]_R`'AZ"``W'MD\"Q[%#KJ?!3JIW_(+B=YXBXI>13J_W]X2^E\%$H_
M?63P'WN"\!A[(``Z>7C#_W]X^P=].-CH?SC(YWR"\#E[>$/G?-`!`>EXRXQ]
M>&/^?R``_7LXT-Y_%$(*?13BB'_(+BAYXBXI>13BYWQX2PE](`"<>>`!`>D4
M2N=\..#I?WA+WG_8`2'I(`#X>!1""GT4ZJA_%$HJ?13::7_(+NEXXB[G>!3:
MWG]X.R=]%#K^?&3P7GN"\%I[(`#Y>'C3WG_(+NAX>/.)?3C@S'\XP"E]XB[G
M>'AC*7UX.P=]%.HI?63P"'L4.BE]@O`8>^@!X>AXPPA]9/`]>WA#WW\@`"QY
M%#KJ?#C(_W^"\#E[%.*'?WC+N7_(+B=YXBXI>2``&WEX2^E\>,L'?3A@YWPX
MV"A_(`#:>WA#YWSP`0'I.-C>?WCS_W\4XO]_%$(*?11*/WT4TDA_(``^><@N
M*'GB+BEY%-+G?'A+"7UD\)]Y%$KG?/@!(>F"\(QY>&/_?R``^GAX^SU_(`#L
M>Q1**GTX\+U_%-II?^(NZ7@H*.=X.&`H?WA+YWQD\,E[@O#>>WA#O7]X\RE]
M%-J]?WA+_W\X8"A].-#_?Q0ZO7]X0_]_``(!Z>(NIWL@`#Q[(``[>11"2GTH
M**A[>#L(?13B2GUD\$=[@O!:>WC3^GP44E]]"`+AZ!1"2GUXTBA]8LH@/7CJ
M"'W6P2EAXBY?>2``*7D@``AY%#KI?!1BAWTH*$=Y>/OG?!1B"'T4.@A]HO"_
M>XCPIWOB+AUY>/O_?!`"X>AX^EY_(`!:>WA2WG\4.NE\(`#>>Q3:9W\H*`=Y
M>.OG?!3:WG\4.MY_B/!'>:+P2GGB+MQ[>%/J?!@"X>AX4OU_(`#_>WA"O7\4
M.NE\(`"]>Q32YWP4ZN=\*"C=>WCCO7\4ZN=\B/`=>:+P"'GB+OQX>$.H?R`"
MH>N(\/MX%.JI?Q3ZO7]X0E]]>/+_?R``2GD@`/][%/J]?R@H_WAXX_]_%/J]
M?XCPWWNB\-Y[XBZ\>WCS_G\H`N'K%/KI?Q12_W]X\@I]>#I*?:+PYW@@`$IY
M>#M[?Q12_W\H**I[>.-*?2``"'D44O]_,`)!Z8CPO'OB+N=[%%))?11"2GUX
MVLA_>.H(?:+PO7L@``AY>.N<?Q1"2GTH*.A[>#L(?7CB9W\40DI].`(!Z2``
MWGMX^N=\(`![>R``YW@40@E]%/((?>(N7GD4.@A]*"A'>7CSYWR(\/Y[%#H(
M?:+P_WM``N'H>/O??^(N'7EX^IY_(`"<>Q0ZZ7QX4MY_%-KG?"``WGL4\N=\
M*"@>>7CKWG^(\%MY2`*AZZ+P2GD4\N=\>%-[?^(N_GAXVNI_%.JI?WA"2GT4
MXKU_(`!*>8CP''D44KU_*"CJ>'CS2GVB\`AY4`+!ZWA#G'\44KU_>.)J?R``
M_WL4\LE_>#I*?13ZWG\@`$IYXBZH>Q12WG\H**I[B/#_>'A#2GVB\.=X%%+>
M?U@"0>EX.^=_>#J(?R``>WMXZ@A]XB[?>Q1227T@``AY%-I*?8CPNWL40DI]
M*"C(>WC["'VB\+U[%$)*?6`"`>EXZWM_>-K_?"``G'MX\O]_XBY=>11""7T@
M`/][%.((?8CPW'L4^@A]*"A?>7CK_W^B\-Y[<`*AZQ3Z"'UH`N'K>/.<?R``
MYWCB+AYY%.JI?Q3ZZ7\4.O]_>.)G?WA2YWP@`'M[(`#G>!3:O7\4.O]_*"@'
M>7CSYWR(\!MY%#K_?XCP1WFB\$IYXB[^>WA3ZGQX4H=_(`"<>WA"YWRB\`AY
M(`#G>'A#>W\4.KU_*"CG>WCSYWQX`L'K>-I(?7CZ"'T4.KU_(``(>>(NIWL4
M\LE_(`!*>13BWG^(\/Q[%$+>?R@HJ'MX.PA]@`+AZ*+P_WMX^YQ_%$+>?^(N
MR'L4.NE\%%+G?'CB:G]XZDI](`![>R``2GD44N=\*"C*>WA#2GV(`@'I%%+G
M?(CPJGNB\+U[XB[_>'CK77T40@E]>.J*?Q3:"'UX\DI](`"<>R``2GD44@A]
M*"CJ>'C[2GV0`N'K%%((?8CPRGNB\-Y[>/->?13ZZ7]X\JI_%.+_?W@Z2GWB
M+AQY(`!*>2``O7L44O]_*"@*>7CC2GT44O]_B/#J>*+PYWCB+OQ[>#M'?9@"
M0>D46F=](`!K>11227T4ZDI]>#K=?R``8_EX0KU_(`#>>R``O7L4ZDI]R"[]
M>WCCO7\4ZDI]B/`=>:+P"'EX0ZA_H`*AZQ3J*7T4`BE]>$+@?'CZ`'P4\BE]
M(```>.(N7GD4`BE]R"Y`>7CS`'P4(DI]%`(I?2``2GD@`"EY%"H(?0@`0_FB
M\.I[(``(>0``(_F(\.E[>%,I?1@``_D4,LE\(`#&>!``P_BH`B'I\(]-Z7E2
M*7T``$`Y#`""0>7&_TL8`$'H\`(A.$P$`$@``````````8`(```"`$P\B"M"
M.*8""'R``&`X$``!^.'_(?A1R_]+&`!!Z$5G0#T@`"$X`2-*80``0_G-[T`]
MB:M*82``2GD(`$/YNIA`/?[<2F$@`$IY$`!#^3(00#UV5$IA&`!#^=+#0#WP
MX4IA(`!*>2``0_D``$`Y>`!#D2@`0_DP`$/Y$``!Z*8#"'P@`(!.````````
M``&``````@!,//0J0CBF`@A\)!^I>&D#`$BQ_R'X>!M^?'@CGWQX*[U\*`!#
MZ112*7T@`"EY0$@J?!``@4`P`$/I`0!*.3``0_EZ`'[H,`!>Z2@`/OE"'ZE[
M.`">.P``(RP42BI],``^^5@`@D%``",A>.N[?P!('7P(`(%`>$L[?;0'>G]X
M^^1_>--%?Q0:?'RIRO]+&`!!Z'@`/H$4VBE]0``)+'@`/I$X`()`4.B[?Q32
M_W^T![U_>//#?S7I_TL_`!TL)`"!07CKI7]X^^1_>..#?V7*_TL8`$'H>`"^
MDU``(3C0`@!(``#_Z`@`'^D0`%_I&``_Z<#_O3M``/\[M`>]?P``_/@(`!SY
M$`!<^1@`//G@___HZ/\?Z?#_7^GX_S_I(`#\^"@`'/DP`%SY.``\^83__TL`
M`````````8`&```"`$P\M"E".*8""'PH`"0Y@/]`.2D"`$BQ_R'X.`"D.W@;
M?GQX(Y]\+$R`?S``)#DL3&!_*``DZ;[N)56B[BEY`0"E.#@`!2RT!Z-\KDE=
M?10:?7PT`8%`0`"E(```@#BT!Z5\\<;_2Q@`0>AX^^-_/>C_2S@`H#@``(`X
M>.NC?]7&_TL8`$'H<`!_DW0`GY-X^^-_&>C_2P``/^EX^^-_`D8I>0``/ID`
M`#_I`H0I>0$`/ID``#_I`L(I>0(`/ID``#_I`P`^F0@`/^D"1BEY!``^F0@`
M/^D"A"EY!0`^F0@`/^D"PBEY!@`^F0@`/^D'`#Z9$``_Z0)&*7D(`#Z9$``_
MZ0*$*7D)`#Z9$``_Z0+"*7D*`#Z9$``_Z0L`/ID8`#_I`D8I>0P`/ID8`#_I
M`H0I>0T`/ID8`#_I`L(I>0X`/ID8`#_I#P`^F2``/^D"1BEY$``^F2``/^D"
MA"EY$0`^F2``/^D"PBEY$@`^F2``/^D3`#Z9_<3_2Q@`0>A0`"$X\```2#@`
MI2```(`XM`>E?.S^_TL``````````8`%``````!@````8````&````!@`@!,
M/``H0CC__X(]0'R,Z?C_X?O__^(_T?\A^$A\_SO__RPL/`""0:8""'P8`$'X
M^/__.T```?@```!@``!"8*8#B7TA!(!.&`!!Z/G_G^G__RPL[/^"0$```>BF
M`PA\,``A./C_X>L@`(!.H/^!^JC_H?JP_\'ZN/_A^L#_`?O(_R'[T/]!^]C_
M8?O@_X'[Z/^A^_#_P?OX_^'[$``!^"``@$Z@_X'JJ/^AZK#_P>JX_^'JP/\!
MZ\C_(>O0_T'KV/]AZ^#_@>L0``'HZ/^AZZ8#"'SP_\'K^/_AZR``@$[P_\'K
M$``!Z/C_X>NF`PA\(`"`3@```&`8I0$``````*8""'P%`)]"I@)H?:8#"'SP
M_POH4&"+?11:8'W4_PPX``"+Z8+P`'BF`XE]"`!KZ2`$@$[,__]+R/__2\3_
M_TO`__]+O/__2[C__TNT__]+L/__2ZS__TNH__]+I/__2Z#__TN<__]+F/__
M2Y3__TN0__]+C/__2XC__TN$__]+@/__2WS__TMX__]+=/__2W#__TML__]+
M:/__2V3__TM@__]+7/__2UC__TM4__]+4/__2TS__TM(__]+1/__2T#__TL\
M__]+./__2S3__TLP__]++/__2RC__TLD__]+(/__2QS__TL8__]+%/__2Q#_
M_TL,__]+"/__2P3__TL`__]+_/[_2_C^_TOT_O]+\/[_2^S^_TOH_O]+`@!,
M/.0E0CBF`@A\$``!^.'_(?@9RO]+````8"``(3@0``'HI@,(?"``@$XO=&UP
M`%!!4E]435!$25(`5$5-4$1)4@!435``55-%4@!54T523D%-10`N+@`E<R\E
M<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z
M`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!
M0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)
M0E)!4EE?4$%42`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P
M87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M
M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4R
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R
M<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)'!A<E]T
M96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF
M:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC
M:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO
M9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I
M;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92!O<B!L87-T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M
M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?
M<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ
M92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD
M;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA
M9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR96%D
M(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C
M:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L(#0["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD
M9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?
M1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D
M('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG
M($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U
M;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M921E
M>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@;W(@<F5T=7)N.PHD
M24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D
M14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2![
M"FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T
M(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^
M<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@
M)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M
M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S
M<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;
M,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C
M;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@
M=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*
M:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@
M0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE
M;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,[
M"G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU
M<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D
M9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E
M("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I
M9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q
M(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q
M)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE
M("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE
M(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M
M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D[
M"G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II
M9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R
M(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T
M.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I
M;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@
M7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@
M=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M
M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"![
M"B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN
M8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E
M>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F
M:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E
M86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O
M*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0[
M"GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@
M*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D
M9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]
M"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[
M)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<
M+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,
M12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*8VQO<V4@)&9H.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E
M9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D
M9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4@
M)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A
M8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC
M:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE
M9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE
M.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H
M:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D
M.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q
M,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!]
M(ETI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B
M92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II
M<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL
M97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA
M;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM
M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]4
M14U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US
M(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE;6)E
M<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U
M+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S
M<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#
M<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@
M1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q
M=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E
M<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W
M87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I
M<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V
M86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X
M('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?
M=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@
M)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I
M9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<[
M"FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K
M("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E
M<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O
M9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E
M<W0["GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?
M.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M
M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"([
M"F]P96X@;7D@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A
M;B=T('=R:71E("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N
M=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`````<&5R;'AS
M:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@```!&P,[V```
M`!H```#4A___A`0``/B,__\(`0``R(W__T`!```HCO__8`$``,R.__^(`0``
M4)#__\0!``#XD/__[`$``!"3__\H`@``=)/__T@"``#LD___;`(``,24__^8
M`@``W)3__ZP"``#LEO___`(``""7__\0`P``A)C__S@#``!$FO__:`,``-":
M__^(`P``')O__Z@#``#@F___W`,``/RB__\@!```K*7__U`$``!$IO__K`0`
M`,R[___L!```8+S__PP%``"@O?__1`4``%3`___P````$``````````!>E(`
M!'A!`1L,`0`4````&````%R___\<`0```$()00!"!D$T````,````.B+___0
M`````$,)00!!F@:;!9P$G0.>`I\!$4%^0@Y02PH.`$+?WMW<V]H&00L``!P`
M``!H````@(S__V``````10YP$4%^30X`0@9!````)````(@```#`C/__I```
M``!%"4$`G@*?`4,.@`$107Y=#@!!W]X&03@```"P````/(W__X0!````0PE!
M`$&8")D'F@:;!9P$G0.>`I\!$4%^00[``@)8#@!!W][=W-O:V=@&020```#L
M````A([__Z@`````1`E!`)\!0P[0`1%!?E\.`$'?!D$````X````%`$```2/
M__\8`@```$,)00!!F0>:!IL%G`2=`YX"GP$107Y!#K`!`GT.`$'?WMW<V]K9
M!D$````<````4`$``."0__]D`````$<.(!%!?DP.`$(&00```"````!P`0``
M))'__W@`````1`E!`)\!1`XP$4%^4@X`0=\&02@```"4`0``>)'__]@`````
M0PE!`$&=`YX"GP$107Y!#J!!;`X`0M_>W09!$````,`!```DDO__&```````
M``!,````U`$``"B2__\0`@```$4)00`12']!E`R5"Y8*EPF8")D'F@:;!9P$
MG0.>`I\!$4%^00[@(@)V#@!$W][=W-O:V=C7UM74!D$&2````!`````D`@``
MZ)/__S0`````````)````#@"```(E/__9`$```!$"4$`GP%##C`107X"3@X`
M0=\&00```"P```!@`@``1)7__\`!````10E!`$&<!)T#G@*?`1%!?D$.L`$"
M90X`0=_>W=P&01P```"0`@``U);__XP`````2PY@$4%^3`X`1`9!````'```
M`+`"``!`E___3`````!%#B`107Y(#@!"!D$````P````T`(``&R7___$````
M`$,)00!!G`2=`YX"GP$107Y!#H`!3@H.`$'?WMW<!D$+````0`````0#``#\
ME___'`<```!%"4$`09<)F`B9!YH&FP6<!)T#G@*?`1%!?D<.\(,"`[4!#@!"
MW][=W-O:V=C7!D$````L````2`,``-2>__^P`@```$,)00!!G0.>`I\!$4%^
M00Z``0*C#@!!W][=!D$````P````>`,``%2A__^8`````$4)00">`I\!0PYP
M$4%^4PH.`$4&0=_>00M!#@!!W]X&00``)````*P#``!(@___7`(```!'#I`!
M$4%^G@*?`0*'"@X`0M_>!D$+`#P```#4`P``D*'__X@5````1`E!`$&8")D'
MF@:;!9P$G0.>`I\!$4%^00[P!0-8!0X`0=_>W=S;VMG8!D$````<````%`0`
M`-BV__^4`````$8.(!%!?D0.`%<&00```#0````T!```3+?__T`!````1`E!
M`$&:!IL%G`2=`YX"GP$107Y!#E!R"@X`0=_>W=S;V@9!"P``,````&P$``!4
MN/__I`$```!%"4$`09L%G`2=`YX"GP$107Y!#E`"6@H.`$'?WMW<VP9!"P``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````__________\``````````/__________````````
M```!`````````-\"`````````0````````#J`@````````\`````````%@0`
M```````,`````````/@7````````#0`````````<60```````/7^_V\`````
M(`(````````%`````````"@,````````!@````````#X`@````````H`````
M````-`0````````+`````````!@`````````%0````````````````````,`
M````````(/T!```````"`````````'`%````````%``````````'````````
M`!<`````````B!(```````````!P`````!18`````````P``<```````````
M``````<`````````8!`````````(`````````"@"````````"0`````````8
M`````````!@```````````````````#[__]O``````$```@`````^?__;P``
M```+````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P````!(60```````'-9````
M``````````````!-60```````$U:````````6%D```````!?6@```````&!9
M``````````````````!D60```````&E9``````````````````#^6P``````
M`$=#0SH@*$%L<&EN92`Q,"XS+C%?9VET,C`R,3`Y,C$I(#$P+C,N,2`R,#(Q
M,#DR,0``+G-H<W1R=&%B`"YI;G1E<G``+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N
M9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(```````````(``````````@```````!X`
M```````````````````!````````````````````$P```/;__V\"````````
M`"`"````````(`(```````#8``````````,`````````"```````````````
M`````!T````+`````@````````#X`@```````/@"````````,`D````````$
M`````P````@`````````&``````````E`````P````(`````````*`P`````
M```H#````````#0$```````````````````!````````````````````+0``
M``0````"`````````&`0````````8!`````````H`@````````,`````````
M"``````````8`````````#<````$````0@````````"($@```````(@2````
M````<`4````````#````$`````@`````````&`````````!!`````0````8`
M````````^!<```````#X%P```````#0````````````````````$````````
M````````````1P````$````&`````````$`8````````0!@```````#<0```
M````````````````(````````````````````$T````!````!@`````````<
M60```````!Q9````````+`````````````````````0`````````````````
M``!3`````0````(`````````2%D```````!(60```````&0^````````````
M```````(````````````````````6P````$````"`````````*R7````````
MK)<```````#<````````````````````!````````````````````&D````!
M`````@````````"(F````````(B8````````H`0```````````````````0`
M``````````````````!S`````0````,`````````0/L!``````!`^P``````
M`!`````````````````````(````````````````````>@````$````#````
M`````%#[`0``````4/L````````0````````````````````"```````````
M`````````($````&`````P````````!@^P$``````&#[````````P`$`````
M```$``````````@`````````$``````````\````"`````,`````````(/T!
M```````@_0```````.`!```````````````````(``````````@`````````
MB@````$````#``````````#_`0```````/\```````!H````````````````
M``````$````````(`````````(\````!`````P````````````(`````````
M`0``````>`````````````````````@```````````````````"5````"```
M``,`````````>``"``````!X``$``````&`0```````````````````(````
M````````````````F@````$````P````````````````````>``!```````Q
M`````````````````````0`````````!``````````$````#````````````
M`````````````*D``0``````HP````````````````````$`````````````
%````````
